.. _github-stats:

GitHub statistics
=================

GitHub statistics for 2021/03/26 - 2021/08/24 (tag: v3.4.0)

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 127 issues and merged 532 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/59?closed=1>`__

The following 115 authors contributed 2695 commits.

* Aaron Rogers
* Abhinav Sagar
* Adrian Price-Whelan
* Adrien F. Vincent
* ain-soph
* Aitik Gupta
* Akiomi Kamakura
* AkM-2018
* Andrea PIERRÉ
* andthum
* Antony Lee
* Antti Soininen
* apodemus
* astromancer
* Bruno Beltran
* Carlos Cerqueira
* Casper da Costa-Luis
* ceelo777
* Christian Baumann
* dan
* Dan Zimmerman
* David Matos
* David Stansby
* dependabot[bot]
* Diego Leal Petrola
* Ellert van der Velden
* Elliott Sales de Andrade
* Eric Firing
* Eric Larson
* Eric Prestat
* Ewan Sutherland
* fourpoints
* Frank Sauerburger
* Gleb Fedorov
* Greg Lucas
* hannah
* Hannes Breytenbach
* Hans Meine
* Harshal Prakash Patankar
* harupy
* Harutaka Kawamura
* Hildo Guillardi Júnior
* Holtz Yan
* Ian Hunt-Isaak
* Ian Thomas
* ianhi
* Illviljan
* ImportanceOfBeingErnest
* iury simoes-sousa
* Jakub Klus
* Janakarajan Natarajan
* Jann Paul Mattern
* Jash Shah
* jeffreypaul15
* Jerome F. Villegas
* Jerome Villegas
* Jesus Briales
* Jody Klymak
* Jonathan Yong
* Joschua Conrad
* Joschua-Conrad
* Jouni K. Seppänen
* K-Monty
* katrielester
* kdpenner
* Kent
* Kent Gauen
* kentcr
* kir0ul
* KM Goh
* Konstantin Popov
* kyrogon
* Leo Singer
* luz paz
* luzpaz
* Madhav Humagain
* Marat Kopytjuk
* Marco Rigobello
* Marco Salathe
* Markus Wesslén
* Matthias Bussonnier
* Michał Górny
* Mihai Anton
* Nico Schlömer
* Phil Nagel
* Philip Schiff
* Philipp Nagel
* pwohlhart
* Quentin Peter
* Ren Pang
* rgbmrc
* Richard Barnes
* richardsheridan
* Ruth Comer
* Ryan May
* Sam Van Kooten
* sandipanpanda
* Slava Ostroukh
* Stefan Appelhoff
* Stefanie Molin
* tdpetrou
* theOehrly
* Thomas A Caswell
* Tim Hoffmann
* tohc1
* Tom Charrett
* Tom Neep
* Tortar
* Tranquilled
* Vagrant Cascadian
* Viacheslav Ostroukh
* Xianxiang Li
* Yo Yehudi
* Zexi
* znstrider

GitHub issues and pull requests:

Pull Requests (532):

* :ghpull:`20883`: Make pywin32 optional in Ctrl+C Qt test.
* :ghpull:`20874`: Add additional external resource.
* :ghpull:`20875`: Use mpl.colormaps in examples
* :ghpull:`20586`: Deprecate matplotlib.test()
* :ghpull:`19892`: Add Figure parameter layout and discourage tight_layout / constrained_layout
* :ghpull:`20882`: Don't add QtNetwork to the API exported by qt_compat.
* :ghpull:`20881`: Deprecate some old globals in qt_compat.
* :ghpull:`13306`: Qt5: SIGINT kills just the mpl window and not the process itself
* :ghpull:`20876`: DOC: Fix dependency link.
* :ghpull:`20878`: Use tables for Locator and Formatter docs
* :ghpull:`20873`: Remove mplutils.cpp; shorten mplutils.h.
* :ghpull:`20872`: Remove some boilerplate from C extension inits.
* :ghpull:`20871`: Move setup.cfg to mplsetup.cfg.
* :ghpull:`20869`: Ignore errors trying to delete make_release_tree.
* :ghpull:`20868`: Fix qt key mods
* :ghpull:`20856`: TST: Add unit test to catch recurrences of #20822, #20855
* :ghpull:`20857`: Propose a less error-prone helper for module-level getattrs.
* :ghpull:`20840`: Speed up Tkagg blit with Tk_PhotoPutBlock
* :ghpull:`20805`: Ensure all params are restored after ``reset_ticks``.
* :ghpull:`20863`: new github citation format
* :ghpull:`20859`: Allow SubFigure legends
* :ghpull:`20848`: Fix PyPy wheels and tests
* :ghpull:`20862`: Fix minor typo in setupext.py
* :ghpull:`20814`: FIX: Avoid copying source script when ``plot_html_show_source_link`` is False in plot directive
* :ghpull:`20855`: BUG: __getattr__ must raise AttributeError if name not found (again)
* :ghpull:`20079`: Prepare axes_divider for simpler(?) indexing-based API.
* :ghpull:`20444`: Delete _Bracket and update the _Curve to be able to ']->' and '<-['
* :ghpull:`20812`: Clarify tutorial "Customizing Matplotlib with style sheets and rcParams"
* :ghpull:`20806`: Deprecate matplotlib.cm.LUTSIZE
* :ghpull:`20818`: Swap Cap/Cup glyphs when using STIX font.
* :ghpull:`20849`: Add external resources to devdoc landing page
* :ghpull:`20846`: Re-re-remove deprecated Qt globals.
* :ghpull:`18503`: Add a dedicated ColormapRegistry class
* :ghpull:`20603`: Deprecate unused LassoSelector event handlers.
* :ghpull:`20679`: Fix selector onselect call when the selector is removed by an "empty" click and add ``ignore_event_outside`` argument
* :ghpull:`11358`: FIX/ENH: Introduce a monolithic legend handler for Line2D
* :ghpull:`20699`: FIX/ENH: Introduce a monolithic legend handler for Line2D
* :ghpull:`20837`: Merge branch v3.4.x
* :ghpull:`18782`: ENH: allow image to interpolate post RGBA
* :ghpull:`20829`: TST: neither warned and pytest upstream deprecated this usage
* :ghpull:`20828`: Increase test timeouts to 60 s to aid slower architectures
* :ghpull:`20816`: ENH: Add the ability to block callback signals
* :ghpull:`20646`: Handle NaN values in ``plot_surface`` zsort
* :ghpull:`20725`: ``Axes3D.plot_surface``: Allow masked arrays and ``NaN`` values
* :ghpull:`20825`: Fix image triage tool with Qt6
* :ghpull:`20229`: ENH: Only do constrained layout at draw...
* :ghpull:`20822`: BUG: __getattr__ must raise AttributeError if name not found
* :ghpull:`20815`: circle: Switch to next-gen image.
* :ghpull:`20813`: add doc-link to dufte
* :ghpull:`20799`: MNT: Rename callbacksSM to callbacks
* :ghpull:`20803`: Re-remove deprecated Qt globals.
* :ghpull:`17810`: FIX: don't fail on first show if animation already exhausted
* :ghpull:`20733`: Deprecate globals using module-level ``__getattr__``.
* :ghpull:`20788`: FIX: Check for colorbar creation with multi-dimensional alpha
* :ghpull:`20115`: ENH: pass extra kwargs in FigureBase, SubFigure, Figure to set
* :ghpull:`20795`: TST/MNT: deprecate unused fixture
* :ghpull:`20792`: Change legend guide to object oriented approach
* :ghpull:`20717`: Fix collection offsets
* :ghpull:`20673`: Point [SOURCE] documents to github
* :ghpull:`19255`: Support for PyQt6/PySide6.
* :ghpull:`20772`: Implement remove_rubberband rather than release_zoom.
* :ghpull:`20783`: Document how to check for the existence of current figure/axes.
* :ghpull:`20778`: Dedupe handling of mouse buttons in macos backend.
* :ghpull:`20749`: Cleanup font subsetting code
* :ghpull:`20775`: Remove some remnants of qt4 support.
* :ghpull:`20659`: Add HiDPI-related config for mathmpl
* :ghpull:`20767`: Factor out latex ifpackageloaded pattern.
* :ghpull:`20769`: Simplify backend_ps._nums_to_str.
* :ghpull:`20768`: Avoid using gca() in examples.
* :ghpull:`20766`: Fix line dash offset format in PS output
* :ghpull:`20706`: Include ``underscore.sty``
* :ghpull:`20729`: Support vmin/vmax with bins='log' in hexbin
* :ghpull:`20753`: Deprecate support for case-insensitive scales.
* :ghpull:`20602`: Merge EllipseSelector example together with RectangleSelector.
* :ghpull:`20744`: Add an example showing alternate mouse cursors.
* :ghpull:`20758`: FIX: pass colorbar.set_ticklabels down to long_axis
* :ghpull:`20759`: Modernize mathtext examples
* :ghpull:`20739`: Small simplifications to streamplot.
* :ghpull:`20756`: Add new external resource: Python Graph Gallery
* :ghpull:`20330`: Fix cla colorbar
* :ghpull:`20688`: issue form files
* :ghpull:`20743`: Set the canvas cursor when using a SpanSelector
* :ghpull:`20391`: Type42 subsetting in PS/PDF
* :ghpull:`20737`: DOC: new index page
* :ghpull:`20686`: Fix interaction between make_keyword_only and pyplot generation.
* :ghpull:`20731`: Improved implementation of Path.copy and deepcopy
* :ghpull:`20732`: Fix style in ``assert(x)``.
* :ghpull:`20620`: Move set_cursor from the toolbar to FigureCanvas.
* :ghpull:`20728`: Fix broken link in 'Contributing' docs
* :ghpull:`20727`: DOC/TST make circle faster
* :ghpull:`20726`: DOC: Provide alternative to cbar.patch
* :ghpull:`20719`: Fix color normalization in plot types scatter
* :ghpull:`20634`: Implement Type-1 decryption
* :ghpull:`20633`: Emit non BMP chars as XObjects in PDF
* :ghpull:`20709`: Fix Circle merge on master branch.
* :ghpull:`20701`: Small cleanup to GTK backend
* :ghpull:`20670`: Support markevery on figure-level lines.
* :ghpull:`20707`: Rename a confusingly named variable in backend_pdf.
* :ghpull:`20680`: CI: Build merged version on CircleCI
* :ghpull:`20471`: add interactive colorbar example to gallery
* :ghpull:`20692`: Small cleanups to hatch.py.
* :ghpull:`20702`: DOC: add note about contouring algorithm
* :ghpull:`18869`: Add __version_info__ as a tuple-based version identifier
* :ghpull:`20689`: Fix some very unlikely leaks in extensions.
* :ghpull:`20254`: Define FloatingAxes boundary patch in data coordinates.
* :ghpull:`20682`: Bump codecov/codecov-action from 1 to 2
* :ghpull:`20544`: Support of different locations for the text fixing cursor of TextBox
* :ghpull:`20648`: Simplify barchart_demo
* :ghpull:`20606`: Dynamically generate CbarAxes.
* :ghpull:`20405`: ENH: expose make_norm_from_scale
* :ghpull:`20555`: Fix the way to get xs length in set_3d_properties()
* :ghpull:`20546`: Improve tutorial figures in the new theme
* :ghpull:`20676`: Fix bounds when initialising ``SpanSelector``
* :ghpull:`20678`: Clarify comment about backend_pgf.writeln.
* :ghpull:`20675`: Shorten the ``@deprecated`` docs.
* :ghpull:`20585`: Rename parameter selectors
* :ghpull:`20672`: Remove outdated parts of MatplotlibDeprecationWarning docs.
* :ghpull:`20671`: Standardize description of kwargs in legend_handler.
* :ghpull:`20669`: Cleanup related to usage of axs
* :ghpull:`20664`: Reword docs about fallbacks on headless linux.
* :ghpull:`20663`: Document $MPLSETUPCFG.
* :ghpull:`20638`: Small simplifications to FixedAxisArtistHelper.
* :ghpull:`20626`: Simplify curvilinear grid examples.
* :ghpull:`20088`: fix some http: -> https: URLs
* :ghpull:`20654`: Remove some usages of plt.setp()
* :ghpull:`20615`: Font 42 kerning
* :ghpull:`20636`: Use set_xticks(ticks, labels) instead of a separate set_xticklabels()
* :ghpull:`20450`: [Doc] Font Types and Font Subsetting
* :ghpull:`20582`: Fix twoslopenorm colorbar
* :ghpull:`20632`: Use ticklabels([]) instead of ticklabels('')
* :ghpull:`20608`: doc/conf.py: if set, use SOURCE_DATE_EPOCH to set copyright year.
* :ghpull:`20605`: Add \dddot and \ddddot as accents in mathtext
* :ghpull:`20621`: TST/DOC: just run circle once...
* :ghpull:`20498`: Adapt the release guide to the new release notes structure
* :ghpull:`20601`: Hide some ``_SelectorWidget`` state internals.
* :ghpull:`20600`: Inline _print_svg into its only call site (print_svg).
* :ghpull:`20589`: Add directional sizing cursors
* :ghpull:`20481`: Deprecate Colorbar.patch.
* :ghpull:`20598`: Don't forget to propagate kwargs from print_svgz to print_svg.
* :ghpull:`19495`: Move svg basename detection down to RendererSVG.
* :ghpull:`20501`: Colorbar redo again!
* :ghpull:`20407`: Turn shared_axes, stale_viewlims into {axis_name: value} dicts.
* :ghpull:`18966`: PR: Remove modality of figure options
* :ghpull:`19265`: Change styling of slider widgets
* :ghpull:`20593`: DOC: fix various typos
* :ghpull:`20374`: Check modification times of included RST files
* :ghpull:`20569`: Better signature and docstring for Artist.set
* :ghpull:`20574`: Add tricontourf hatching example
* :ghpull:`18666`: Remove unused/deprecated AVConv_ classes
* :ghpull:`20514`: Fix example for rcParams['autolimit_mode']
* :ghpull:`20571`: Switch default ArrowStyle angle values from None to zero.
* :ghpull:`20510`: Consistent capitalization of section headers
* :ghpull:`20573`: Move the marker path example into the marker reference
* :ghpull:`20572`: Clarify allowable backend switches in matplotlib.use().
* :ghpull:`20538`: Show box/arrowstyle parameters in reference examples.
* :ghpull:`20515`: Shorten the implementation of bxp().
* :ghpull:`20562`: More concise how to for subplot adjustment
* :ghpull:`20570`: Reduce vertical margins in property tables
* :ghpull:`20563`: Expire deprecation of passing nbins to MaxNLocator in two ways
* :ghpull:`20561`: Fix limits in plot types example hist(x)
* :ghpull:`20559`: Fix deprecation of encoding in plot_directive.
* :ghpull:`20547`: Raise if passed invalid kwargs to set_constrained_layout_pads.
* :ghpull:`20527`: Factor out DEBUG_TRUETYPE checks in ttconv, & removals of unused defs.
* :ghpull:`20465`: Remove remaining 3.3 deprecations
* :ghpull:`20558`: Rename recently introduced parameters in SpanSelector
* :ghpull:`20535`: Improve the documentation guide
* :ghpull:`20113`: Interactive span selector improvement
* :ghpull:`20524`: Dedupe some box anchoring code between legend.py and offsetbox.py.
* :ghpull:`20451`: Add initial TextBox widget testing
* :ghpull:`20543`: Deprecate ``@pytest.mark.style(...)``.
* :ghpull:`20530`: Plot nothing for incompatible 0 shape in x,y data
* :ghpull:`20367`: Add parse_math in Text and default it False for TextBox
* :ghpull:`20509`: Cleanup plot types
* :ghpull:`20537`: Don't sort boxstyles/arrowstyles/etc. alphabetically.
* :ghpull:`20542`: Fix ScalarFormatter.format_ticks for non-ordered tick locations.
* :ghpull:`20533`: Rename (N, M) -> (M, N) array-like
* :ghpull:`20540`: Deprecate :encoding: option to .. plot::, which has no effect since 2011
* :ghpull:`20541`: Minor fix
* :ghpull:`20539`: Document defaults in plot_directive.
* :ghpull:`20536`: Make most of annotation tutorial a comment, and remove figure titles.
* :ghpull:`20439`: Remove dead code from LGTM alerts.
* :ghpull:`20528`: Merge subplot_demo into subplot example.
* :ghpull:`20493`: Cleanup AnchoredOffsetbox-related demos.
* :ghpull:`20513`: Shorten the bxp docstring.
* :ghpull:`20507`: Merge subplot_toolbar example into subplots_adjust.
* :ghpull:`20505`: Add rc_context to customizing tutorial
* :ghpull:`20449`: Suppress repeated logwarns in postscript output.
* :ghpull:`20500`: DOC: Add twitter icon and fix logo link
* :ghpull:`20499`: Simplify plot types pie()
* :ghpull:`20495`: Fix shape of Z in contour docs
* :ghpull:`20497`: Remove obsolete footnote on pyside
* :ghpull:`20485`: DOC: hexbin 'extent' must be 4-tuple of float, not float
* :ghpull:`20466`: Various cleanups to pgf backend.
* :ghpull:`20474`: Make lack of support more explicit for non-postscript fonts + usetex.
* :ghpull:`20476`: give Font a root widget
* :ghpull:`20477`: remove _master attribute from FigureCanvasTk
* :ghpull:`19731`: DOC: first pass at switching to pydata theme
* :ghpull:`20475`: Less pyplot, more OO in docs.
* :ghpull:`20467`: Small cleanups to sphinxext.plot_directive.
* :ghpull:`20437`: Use packaging to do version comparisons.
* :ghpull:`20354`: Merge Colorbar and ColorbarBase.
* :ghpull:`20464`: tinypages/conf.py doesn't need to manipulate sys.path.
* :ghpull:`20420`: Add a select_overload helper for signature-overloaded functions.
* :ghpull:`20460`: Shorten the AnchoredOffsetbox docstring.
* :ghpull:`20458`: Set the axes of legend text
* :ghpull:`20438`: Fix deprecation of ``Tick.apply_tickdir``.
* :ghpull:`20457`: Rename data variables in histogram example.
* :ghpull:`20442`: Fix dvi baseline detector when ``\usepackage{chemformula}`` is used.
* :ghpull:`20454`: Tell LGTM to use Python 3 explicitly.
* :ghpull:`20446`: Make used tex packages consistent between ps and other backends.
* :ghpull:`20447`: Remove Figure/Axes/Axis deprecations from 3.3
* :ghpull:`20414`: ENH: add colorbar info to gridspec cbar
* :ghpull:`20436`: Add missing super __init__ in subclasses
* :ghpull:`20284`: Use a GtkApplication in GTK backend.
* :ghpull:`20400`: Make pdftex.map parsing stricter
* :ghpull:`20292`: Cleanup plot types docs
* :ghpull:`20445`: Small cleanups to backend_ps.
* :ghpull:`20399`: Improve example for 3D polygons
* :ghpull:`20432`: Small doc cleanups.
* :ghpull:`20398`: Document Axes.get_aspect()
* :ghpull:`20428`: Deprecate public use of get_path_in_displaycoord.
* :ghpull:`20397`: Improve hexbin() documentation
* :ghpull:`20430`: Improve fancyarrow_demo.
* :ghpull:`20431`: Fix indentation of Arrow/Box/Connection styles tables.
* :ghpull:`20427`: Fix references in ArrowStyle docstring.
* :ghpull:`20346`: Clarify/Improve docs on family-names vs generic-families
* :ghpull:`20410`: PGF: Clip lines/markers to maximum LaTeX dimensions.
* :ghpull:`20363`: Don't disable path clipping on paths with codes.
* :ghpull:`20244`: Inline and simplify SubplotToolQt.
* :ghpull:`20165`: Slightly improve output of dvi debug utilities, and tiny cleanups.
* :ghpull:`20390`: Cleanup arrow_demo.
* :ghpull:`20408`: Remove mention of now-removed Encoding class.
* :ghpull:`20327`: FIX: fix colorbars with no scales
* :ghpull:`20215`: Quadmesh.set_array validates dimensions
* :ghpull:`20293`: Simplify font setting in usetex mode
* :ghpull:`20386`: Merge arrow_simple_demo into arrow_guide.
* :ghpull:`20348`: codecs.getwriter has simpler lifetime semantics than TextIOWrapper.
* :ghpull:`20132`: Create release notes page
* :ghpull:`20331`: Remove Axis, Tick, and Axes deprecations from 3.3
* :ghpull:`20373`: Handle direction="column" in axes_grid.Grid
* :ghpull:`20394`: Remove separate section for support of 3d subplots.
* :ghpull:`20393`: Remove non-informative figure captions.
* :ghpull:`17453`: Displaying colorbars with specified boundaries correctly
* :ghpull:`20369`: Switch version scheme to release-branch-semver.
* :ghpull:`20377`: Cleanup some examples titles & texts.
* :ghpull:`20378`: Redirect agg_buffer{,_to_array} examples to canvasagg.
* :ghpull:`20376`: Small improvements to canvasagg example.
* :ghpull:`20365`: Reorganize a bit text-related rcs in matplotlibrc.
* :ghpull:`20362`: Add research notice
* :ghpull:`20353`: Remove incorrect statement about data-kwarg interface.
* :ghpull:`20343`: Fix exception handling when constructing C-level PathGenerator.
* :ghpull:`20349`: Fix missing write in TTStreamWriter::printf.
* :ghpull:`20347`: Fix possible refleak in PathGenerator.
* :ghpull:`20339`: Cleanup autoscale-related docstrings.
* :ghpull:`20338`: Fix some indent-related style lints.
* :ghpull:`20337`: Small unit-related cleanups.
* :ghpull:`20168`: FIX: clean up re-limiting hysteresis
* :ghpull:`20336`: Deduplicate color format specification
* :ghpull:`20334`: Remove need for ConversionInterface to support unitless values.
* :ghpull:`20020`: For polar plots, report cursor position with correct precision.
* :ghpull:`20319`: DOC: Tweaks to module API pages
* :ghpull:`20332`: Quadmesh's default value of shading is now set to 'flat' instead of False
* :ghpull:`20333`: Better align param comments in ``Legend.__init__`` signature.
* :ghpull:`20323`: Adding cla and remove to ColorbarAxes
* :ghpull:`20320`: Fix remaining E265 exceptions.
* :ghpull:`20318`: DOC: Fix missing refs in what's new pages
* :ghpull:`20315`: Fix spelling.
* :ghpull:`20291`: Write data parameter docs as regular parameter not as note (v2)
* :ghpull:`19908`: Implement get_cursor_data for QuadMesh.
* :ghpull:`20314`: MAINT: Removing deprecated colorbar functions.
* :ghpull:`20310`: Add test for font selection by texmanager.
* :ghpull:`19348`: Make YearLocator a subclass of RRuleLocator
* :ghpull:`20208`: Rewrite blocking_input to something much simpler.
* :ghpull:`19033`: Templatize class factories.
* :ghpull:`20309`: DOC: Spell out args/kwargs in examples/tutorials
* :ghpull:`20305`: Merge two axisartist examples and point to standard methods.
* :ghpull:`20306`: Document legend(handles=handles) signature
* :ghpull:`20311`: Warn if a non-str is passed to an rcParam requiring a str.
* :ghpull:`18472`: Adding a get_coordinates() method to Quadmesh collections
* :ghpull:`20032`: axvline()/axvspan() should not update r limits in polar plots.
* :ghpull:`20304`: Don't mention dviread in the PsfontsMap "missing entry" error message.
* :ghpull:`20308`: Remove outdated comment re: pgf/windows.
* :ghpull:`20302`: Further remove use of meshWidth, meshHeight in QuadMesh.
* :ghpull:`20101`: Fix ``Text`` class bug when ``font`` argument is provided without ``math_fontfamily``
* :ghpull:`15436`: Allow imshow from float16 data
* :ghpull:`20299`: Simplify tfm parsing.
* :ghpull:`20290`: Support imshow(<float16 array>).
* :ghpull:`20303`: Remove tilde in code links where not necessary
* :ghpull:`19873`: Allow changing the vertical axis in 3d plots
* :ghpull:`19558`: Use luatex in --luaonly mode to query kpsewhich.
* :ghpull:`20301`: Clarify the effect of PolygonCollection properties on Quiver
* :ghpull:`20235`: Warn user when mathtext font is used for ticks
* :ghpull:`20237`: Make QuadMesh arguments with defaults keyword_only
* :ghpull:`20054`: Enh better colorbar axes
* :ghpull:`20164`: Auto-generate required kwdoc entries into docstring.interpd.
* :ghpull:`19677`: Convert axis limit units in Qt plot options widget
* :ghpull:`14913`: Reimplement NonUniformImage, PcolorImage in Python, not C.
* :ghpull:`20295`: Replace text._wrap_text by _cm_set().
* :ghpull:`19859`: Write data parameter docs as regular parameter not as note
* :ghpull:`20273`: Fix cursor with toolmanager on GTK3.
* :ghpull:`20288`: Small markup fixes in api docs.
* :ghpull:`20276`: Tiny fixes to mathtext/usetex tutorials.
* :ghpull:`20084`: Add legend.labelcolor in rcParams
* :ghpull:`19253`: Improve font spec for SVG font referencing.
* :ghpull:`20278`: Deprecate public access to certain texmanager attributes.
* :ghpull:`19375`: Don't composite path-clipped image; forward suppressComposite as needed.
* :ghpull:`20190`: Simplify handling of uncomparable formats in tests.
* :ghpull:`20277`: Fix ordering of tex font usepackages.
* :ghpull:`20279`: Slightly reword intros of mpl_toolkits API docs.
* :ghpull:`20272`: De-duplicate fonts in LaTeX preamble.
* :ghpull:`15604`: Deprecate auto-removal of grid by pcolor/pcolormesh.
* :ghpull:`20193`: Simplify HostAxes.draw and its interaction with ParasiteAxes.
* :ghpull:`19441`: Make backend_gtk3foo importable on headless environments.
* :ghpull:`20126`: Simplify font_manager font enumeration logic.
* :ghpull:`19869`: Factor out x/y lo/hi handling in errorbar.
* :ghpull:`20173`: Rename (with deprecation) first parameter of grid() from b to visible.
* :ghpull:`19499`: Fully fold overset/underset into _genset.
* :ghpull:`20268`: Api pcolorargs deprecation
* :ghpull:`20264`: Fix blitting selector
* :ghpull:`20081`: Limit documenting special members to __call__
* :ghpull:`20245`: MAINT: Removing deprecated ``offset_position`` from Collection
* :ghpull:`20218`: Update Axes showcase in "Embedding in Tk" example
* :ghpull:`20019`: Example: Cursor widget with text
* :ghpull:`20242`: Add comments and format Axis._get_coord_info
* :ghpull:`20207`: Move axisartist towards using standard Transforms.
* :ghpull:`20247`: Explicitly reject black autoformatting.
* :ghpull:`20217`: ci: Export sphinx-gallery run results to CircleCI.
* :ghpull:`20238`: Clarify docstring of ScalarMappable.set/get_array()
* :ghpull:`20239`: Style tables in style guide
* :ghpull:`19894`: Remove deprecated Qt4 backends
* :ghpull:`19937`: Add washing machine to Axes3D
* :ghpull:`20233`: Add a Ubuntu 20.04 / Python 3.9 CI run
* :ghpull:`20227`: Adding an equals method to colormaps
* :ghpull:`20216`: Documentation Style Guide for contributors
* :ghpull:`20222`: Fix C coverage
* :ghpull:`20221`: DOC: clarify that savefig(..., transparent=False) has no effect
* :ghpull:`20047`: Add labels parameter to set_ticks()
* :ghpull:`20118`: Convert FontEntry to a data class
* :ghpull:`19167`: Add support for HiDPI in TkAgg on Windows
* :ghpull:`18397`: fix cmr10 negative sign in cmsy10 (RuntimeWarning: Glyph 8722 missing)
* :ghpull:`20170`: SubplotParams.validate-associated fixes.
* :ghpull:`19467`: Shorten the implementation of violin().
* :ghpull:`12226`: FIX: pcolor/pcolormesh honour edgecolors kwarg when facecolors is set 'none'
* :ghpull:`18870`: Expand ScalarMappable.set_array to accept array-like inputs
* :ghpull:`20073`: Support SubFigures in AxesDivider.
* :ghpull:`20209`: Deprecate cbook.report_memory.
* :ghpull:`20211`: Use check_getitem in legend location resolution.
* :ghpull:`20206`: Cleanup axisartist in preparation for future changes.
* :ghpull:`20191`: Small simplifications to FloatingAxesBase.
* :ghpull:`20189`: Add tests for ginput and waitforbuttonpress.
* :ghpull:`20199`: Make set_marker{edge,face}color(None) more consistent.
* :ghpull:`16943`: Changing get_cmap to return copies of the registered colormaps.
* :ghpull:`19483`: MNT: deprecate epoch2num/num2epoch
* :ghpull:`20201`: Simplify _process_plot_var_args.set_prop_cycle.
* :ghpull:`20197`: Speedup Line2D marker color setting.
* :ghpull:`20194`: Fix markup on MEP22.
* :ghpull:`20198`: Fix validation of Line2D color.
* :ghpull:`20046`: Deprecation warning
* :ghpull:`20144`: More tight_layout cleanups
* :ghpull:`20105`: Shorten Curve arrowstyle implementations.
* :ghpull:`19401`: Simplify axisartist line clipping.
* :ghpull:`19260`: Update round fix
* :ghpull:`20196`: Replaced links to colormap packages with link to third-party packages list in MPL docs
* :ghpull:`18819`: Usage guide edit
* :ghpull:`18346`: Soft-deprecate Axes.plot_date()
* :ghpull:`20187`: Merge v3.4.x up into master
* :ghpull:`15333`: Enh: DivergingNorm Fair
* :ghpull:`20188`: Remove 3.3 deprecations in cbook.
* :ghpull:`20177`: Fix broken test re: polar tick visibility.
* :ghpull:`20026`: DOC: move third-party packages to new page
* :ghpull:`19994`: Don't hide shared "x/y"ticklabels for grids of non-rectilinear axes.
* :ghpull:`20150`: Rename mosaic layout
* :ghpull:`19369`: Add Artist._cm_set for temporarily setting an Artist property.
* :ghpull:`15889`: Add svg logo icon
* :ghpull:`20140`: DOC: make 2x versions of all gallery figures
* :ghpull:`20155`: Fix wheel builds on CI
* :ghpull:`19951`: Convert Qhull wrapper to C++ and array_view
* :ghpull:`19918`: Cleanup some consistency in contour extensions
* :ghpull:`20153`: Fix wheel builds on CI
* :ghpull:`19363`: Create box3d example
* :ghpull:`20129`: Cleanup some "variable assigned but not used" lints.
* :ghpull:`20107`: Support full-sharex/y in subplot_mosaic.
* :ghpull:`20094`: Switch _auto_adjust_subplotpars to take rowspan/colspan as input.
* :ghpull:`16368`: Improve warning for unsupported scripts.
* :ghpull:`19660`: Allow PolygonSelector points to be removed
* :ghpull:`16291`: Split Norm and LinearNorm up
* :ghpull:`20119`: Cleanup flake8 exceptions for examples
* :ghpull:`20109`: Fix trailing text in doctest-syntax plot_directive.
* :ghpull:`19538`: Speedup pdftex.map parsing.
* :ghpull:`20003`: Bump minimum NumPy to 1.17
* :ghpull:`20074`: Copy-edit axes_grid tutorial.
* :ghpull:`20124`: Remove workaround unneeded on Py3.7+, which we require now.
* :ghpull:`20120`: Cleanup subsetting tool.
* :ghpull:`20108`: Skip back-and-forth between pixels and points in contour code.
* :ghpull:`20106`: Shorten bracket arrowstyle docs.
* :ghpull:`20090`: Cleanup anchored_artists, inset_locator docstrings.
* :ghpull:`20097`: Use nullcontext more as do-nothing context manager.
* :ghpull:`20095`: Remove 3.3 ticker deprecations
* :ghpull:`20064`: Expire deprecation of AxesDivider defaulting to zero pads.
* :ghpull:`20091`: Cleanup tight_layout.
* :ghpull:`20069`: Don't make VBoxDivider inherit from HBoxDivider.
* :ghpull:`20078`: Remove some usages of OrderedDict
* :ghpull:`20077`: Expire Artist.set() property reordering
* :ghpull:`20070`: Harmonize descriptions of the 'anchor' parameter.
* :ghpull:`20011`: Move development dependencies to dependencies page
* :ghpull:`20072`: Improve labeling in simple_axes_divider1 example.
* :ghpull:`20063`: Deprecate some untested, never used axes_grid1 methods.
* :ghpull:`20065`: Deprecate AxesDivider.append_axes(..., add_to_figure=True).
* :ghpull:`20066`: Cleanup axes_divider docstrings, and detail calculations.
* :ghpull:`20059`: Include left and right titles for labeling axes in qt axes selector.
* :ghpull:`20052`: Remove axes_grid/axisartist APIs deprecated in Matplotlib 3.3.
* :ghpull:`18807`: make FancyArrow animatable
* :ghpull:`15281`: Don't use ImageGrid in demo_text_rotation_mode.
* :ghpull:`20051`: Remove offsetbox APIs deprecated in Matplotlib 3.3.
* :ghpull:`14854`: Improved dev installation documentation
* :ghpull:`18900`: Enh better colorbar axes
* :ghpull:`20042`: DOC: fix typos
* :ghpull:`13860`: Deprecate {Locator,Formatter}.set_{{view,data}_interval,bounds}.
* :ghpull:`20028`: Shorten the repr of scaling transforms.
* :ghpull:`20027`: Fix axvspan for drawing slices on polar plots.
* :ghpull:`20024`: Small fixes to latex-related docs.
* :ghpull:`20023`: Simplify _redo_transform_rel_fig.
* :ghpull:`20012`: Fix default theta tick locations for non-full-circle polar plots.
* :ghpull:`20021`: DOC: fix typos
* :ghpull:`20013`: Move restriction of polar theta scales to ThetaAxis._set_scale.
* :ghpull:`20010`: DOC: fix heading level for plot_types/stats
* :ghpull:`20000`: Remove ax fixture from category tests.
* :ghpull:`20007`: Correct minor typos in legend.py and autoscale.py
* :ghpull:`20005`: DOC: Fix numpydoc syntax, and parameters names.
* :ghpull:`19996`: Small simplification to RadialLocator.
* :ghpull:`19968`: ENH: draw no output
* :ghpull:`19657`: Allow Selectors to be dragged from anywhere within their patch
* :ghpull:`19304`: Add legend title font properties
* :ghpull:`19977`: Fix doc build
* :ghpull:`19974`: CI: update the ssh key used to push the devdocs
* :ghpull:`9888`: Add an Annulus patch class
* :ghpull:`13680`: Update seaborn style
* :ghpull:`19967`: ENH: add user-facing no-output draw
* :ghpull:`19765`: ENH: use canvas renderer in draw
* :ghpull:`19525`: Don't create page transparency group in pdf output (for pdftex compat).
* :ghpull:`19952`: avoid implicit np.array -> float conversion
* :ghpull:`19931`: Remove now unused patches to ttconv.
* :ghpull:`19934`: Deprecate drawtype to RectangleSelector
* :ghpull:`19941`: Simplify 3D random walk example
* :ghpull:`19926`: Move custom scales/custom projections docs to module docstrings.
* :ghpull:`19898`: Remove 3.3 backend deprecations
* :ghpull:`19901`: Remove 3.3 rcParam deprecations
* :ghpull:`19900`: Remove 3.3 text deprecations
* :ghpull:`19922`: Remove 3.3 deprecated modules
* :ghpull:`19925`: Include projections.geo in api docs.
* :ghpull:`19924`: Discourage use of imread & improve its docs.
* :ghpull:`19866`: Switch to asciiart for boxplot illustration.
* :ghpull:`19912`: Add symlog to figureoptions scalings
* :ghpull:`19564`: Micro-optimize type1font loading
* :ghpull:`19623`: FIX: Contour lines rendered incorrectly when closed loops
* :ghpull:`19902`: Implement ArtistList.__[r]add__.
* :ghpull:`19904`: Don't set zoom/pan cursor for non-navigatable axes.
* :ghpull:`19909`: Use unicode when interactively displaying 3d azim/elev.
* :ghpull:`19905`: pyplot: do not apply kwargs twice in to x/yticklabels
* :ghpull:`19126`: Move pixel ratio handling into FigureCanvasBase
* :ghpull:`19897`: DOC/MNT fix make clean for plot_types
* :ghpull:`19858`: Move Line2D units handling to Axes & deprecate "units finalize" signal.
* :ghpull:`19889`: Include length in ArtistList repr.
* :ghpull:`19887`: Fix E265 in test files.
* :ghpull:`19882`: Use ax.set() for a more compact notation of styling in plot types docs
* :ghpull:`17231`: Fix errobar order
* :ghpull:`19703`: DOC:  new plot gallery
* :ghpull:`19825`: Factor out machinery for running subprocess tk tests.
* :ghpull:`19872`: Fix unit handling in errorbar for astropy.
* :ghpull:`19526`: Apply unit conversion early in errorbar().
* :ghpull:`19855`: Correct handle default backend.
* :ghpull:`18216`: Combine Axes.{lines,images,collections,patches,text,tables} into single list
* :ghpull:`19853`: Consistent corner variables names in widgets.py
* :ghpull:`19575`: Deprecate Text.get_prop_tup.
* :ghpull:`19810`: Remove JPEG-specific parameters and rcParams.
* :ghpull:`19666`: Change dictionary to list of tuples to permit duplicate keys
* :ghpull:`19400`: Fix tk event coordinates in the presence of scrollbars.
* :ghpull:`19603`: Remove matplotlibrc.template.
* :ghpull:`19835`: Merge v3.4.x into master
* :ghpull:`19821`: Hide stderr output from subprocess call in test suite.
* :ghpull:`19819`: Correct small typos in _axes.py and legend.py
* :ghpull:`19795`: Remove usetex-related APIs deprecated in Matplotlib 3.3.
* :ghpull:`19789`: Fix zorder handling for OffsetBoxes and subclasses.
* :ghpull:`19796`: Expire ````keymap.all_axes````-related deprecations.
* :ghpull:`19806`: Remove outdated api changes notes.
* :ghpull:`19801`: Expire deprecation of mathtext.fallback_to_cm.
* :ghpull:`12744`: Explicit plotorder
* :ghpull:`19681`: Merge branch 'v3.4.x' into master
* :ghpull:`18971`: Switch to setuptools_scm.
* :ghpull:`19727`: DOC: simplify API index
* :ghpull:`19760`: Speed up _delete_parameter.
* :ghpull:`19756`: Minor cleanup of documentation guide
* :ghpull:`19752`: Cleanup backend_tools docstrings, and minor refactorings.
* :ghpull:`19552`: Remove scalarmappable private update attributes
* :ghpull:`19728`: Factor out clip-path attr handling in backend_svg.
* :ghpull:`19540`: Share subplots() label visibility handling with label_outer().
* :ghpull:`19753`: Cleanup string formatting in backend_pgf.
* :ghpull:`19750`: Simplify maxdict implementation.
* :ghpull:`19749`: Remove unused _find_dedent_regex & _dedent_regex.
* :ghpull:`19751`: Update some matplotlib.lines docstrings.
* :ghpull:`13072`: ENH: add figure.legend; outside kwarg for better layout outside subplots
* :ghpull:`19740`: Minor backend docstring fixes.
* :ghpull:`19734`: Remove unused _fonts attribute in RendererSVG.
* :ghpull:`19733`: Reword AutoDateFormatter docs.
* :ghpull:`19718`: Small style fixes to matplotlibrc.template.
* :ghpull:`19679`: Add inheritance diagram to patches docs
* :ghpull:`19717`: Don't sort lexicographially entries in SVG output.
* :ghpull:`19716`: Fix colon placement in issue template.
* :ghpull:`19704`: Cleanup license page in docs
* :ghpull:`19487`: Deprecate unused \*args to print_<foo>.
* :ghpull:`19654`: Dedupe various method implementations using functools.partialmethod.
* :ghpull:`19655`: Deprecate Tick.apply_tickdir.
* :ghpull:`19653`: deprecate_privatize_attribute also works for privatizing methods.
* :ghpull:`19646`: Add angle setter/getter to Rectangle
* :ghpull:`19659`: Improve docs for rgba conversion
* :ghpull:`19641`: Fix Bbox.frozen() not copying minposx/minposy
* :ghpull:`19626`: Clean up E265 in examples.
* :ghpull:`19622`: Prefer Axes.remove() over Figure.delaxes() in docs.
* :ghpull:`19621`: Dedupe docstrings of Figure.{get_axes,axes}.
* :ghpull:`19600`: DOC: better intro for dates.py
* :ghpull:`19606`: Remove versionadded notes; correct doc link
* :ghpull:`19620`: Remove suggestion to remove rk4/rk45 integrators from streamplot.
* :ghpull:`19586`: DOC: more improve date example
* :ghpull:`19566`: add docstring to ax.quiver
* :ghpull:`19601`: Handle None entries in sys.modules.
* :ghpull:`19517`: Deprecate toplevel is_url, URL_REGEX helpers.
* :ghpull:`19570`: Dedupe part of error message in check_in_list.
* :ghpull:`14508`: Add force_zorder parameter
* :ghpull:`19585`: Deprecate trivial helpers in style.core.
* :ghpull:`19534`: BUG: fill_between with interpolate=True and NaN.
* :ghpull:`18887`: FIX: Generalize Colorbar Scale Handling
* :ghpull:`16788`: Adding png image return for inline backend figures with _repr_html_

Issues (127):

* :ghissue:`20791`: [Bug]: spines and ticklabels
* :ghissue:`20723`: Adding a legend to a ``SubFigure`` doesn't work
* :ghissue:`20637`: PyPy wheels are pinned to v3.3, so pypy-based wheels for latest versions are not available
* :ghissue:`19160`: pypy failures
* :ghissue:`20385`: Add ']->' , '<-[' arrowstyles
* :ghissue:`19016`: Move away from set_ticklabels()
* :ghissue:`20800`: [Bug]: Setting backend in custom style sheet raises UserWarning
* :ghissue:`20809`: [Bug]: \Cap and \Cup in mathtext are inconsistent
* :ghissue:`20762`: [Doc]: Add external resources to devdoc landing page
* :ghissue:`18490`: Add a method to access the list of registered colormaps
* :ghissue:`20666`: Interactive SpanSelector no longer notifies when the selector is removed by an "empty" click
* :ghissue:`20552`: Expose legend's line: ``legline._legmarker`` as public
* :ghissue:`18391`: Bug? Legend Picking Not Working on Marker
* :ghissue:`11357`: Unable to retrieve marker from legend handle
* :ghissue:`2035`: legend marker update bug
* :ghissue:`19748`: Incorrect & inconsistent coloring in .imshow() with LogNorm
* :ghissue:`18735`: imshow padding around NaN values
* :ghissue:`7928`: [Bug] backend_bases.key_press_handler sneakily uses digit keys
* :ghissue:`20802`: Add ability to disable callbacks temporarily
* :ghissue:`16470`: Inconsistent Corner Masking w/ plot_surface
* :ghissue:`12395`: Rendering issue occurs when plotting 3D surfaces at a discontinuity
* :ghissue:`8222`: matplotlib 3D surface - gaps / holes in surface
* :ghissue:`4941`: Axes3d plot_surface not supporting masked arrays?
* :ghissue:`487`: Plotting masked arrays with plot_surface()
* :ghissue:`20794`: [Doc]: "Bachelor's degrees by gender" example is more or less dufte
* :ghissue:`20557`: Have ``[Source]`` in api docs link to github
* :ghissue:`20754`: [Doc]: legend guide should be OO
* :ghissue:`17770`: animation.save and fig.savefig interfere with each other and raise StopIteration
* :ghissue:`20785`: [Bug]: Colorbar creation from pcolormesh with cell specific alpha values
* :ghissue:`19843`: collection with alpha + colorer
* :ghissue:`20698`: collections.Collections offset improvements
* :ghissue:`17774`: Cannot make Latex plots when Pandas dataframe has underscore in variable name
* :ghissue:`19884`: Better document Axes.set()
* :ghissue:`20760`: [Bug]: subfigure position shifts on y-axis when x kwarg added to supxlabel
* :ghissue:`20296`: colorbar set_ticklabels - text properties not working
* :ghissue:`18191`: PostScript Type42 embedding is broken in various ways
* :ghissue:`11303`: Using fonttype 42 will make the produced PDF size considerably larger when the image has Chinese characters
* :ghissue:`20735`: The top level of the docs needs modification
* :ghissue:`20684`: make_keyword_only doesn't work for pyplot-wrapped methods
* :ghissue:`20635`: DOC: Document patch deprecation
* :ghissue:`17473`: Issue with appearance of RectangleSelector
* :ghissue:`20616`: Type 42 chars beyond BMP not displayed in PDF
* :ghissue:`20658`: MAINT: CircleCI build merged PRs
* :ghissue:`18312`: Add easily comparable version info to toplevel
* :ghissue:`20665`: interactive SpanSelector incorrectly forces axes limits to include 0
* :ghissue:`20614`: Missing kerning in PDFs with Type 42 font
* :ghissue:`20640`: Column direction breaks label mode L for AxesGrid.
* :ghissue:`20581`: Change in custom norm colour map display
* :ghissue:`20595`: Triple and quadruple dot Mathtext accents don't stack or align.
* :ghissue:`19755`: Avoid showing a black background before the plot is ready with Qt5agg backend
* :ghissue:`10235`: Why not get the same clear image on a high-resolution screen?
* :ghissue:`20479`: ColorbarAxes is an imperfect proxy for the Axes passed to Colorbar
* :ghissue:`18965`: Figure options with qt backend breaks
* :ghissue:`19256`: New Styling for Sliders
* :ghissue:`14148`: zorder ignored in mplot3d
* :ghissue:`20523`: plot_directive is confused by include directives, part 2 (context option)
* :ghissue:`17860`: Plot directive may be confused by ``..include::``
* :ghissue:`19431`: Tricontour documentation and examples should be updated in line with contour
* :ghissue:`20508`: rcParams['axes.autolimit_mode'] = 'round_numbers' is broken
* :ghissue:`20289`: Simplify font setting in usetex mode
* :ghissue:`20370`: Test Coverage for TextBox
* :ghissue:`20522`: Improve 'Writing ReST Pages' section on docs
* :ghissue:`19259`: Set legend title font properties
* :ghissue:`18305`: Support simple axes shares in subplot_mosaic
* :ghissue:`20049`: add legend.labelcolor "argument" to mplstyle stylesheet
* :ghissue:`20452`: Wrong/not useful error message when plotting incompatible x and y
* :ghissue:`20266`: "$$" can not be displayed by ax.text()
* :ghissue:`20517`: Wrong shape of Z in documentation of contour
* :ghissue:`19423`: Switch to pydata-sphinx-theme
* :ghissue:`20435`: Legend Text's ``axes`` attribute is ``None``
* :ghissue:`20379`: Change name of variables in histogram example
* :ghissue:`20440`: Wrong text vertical position with LaTeX enabled
* :ghissue:`10042`: Inconsistent use of graphicx and color packages in LaTeX preambles
* :ghissue:`4482`: PGF Backend: "Dimension too large" error while processing log-scale plot
* :ghissue:`20324`: New colorbar doesn't handle norms without a scale properly...
* :ghissue:`17508`: Quadmesh.set_array should validate dimensions
* :ghissue:`20372`: Incorrect axes positioning in axes_grid.Grid with direction='column'
* :ghissue:`19419`: Dev version hard to check
* :ghissue:`17310`: Matplotlib git master version fails to pass serveral pytest's tests.
* :ghissue:`7742`: plot_date() after axhline() doesn't rescale axes
* :ghissue:`20322`: QuadMesh default for shading inadvertently changed.
* :ghissue:`9653`: SVG savefig + LaTeX extremely slow on macOS
* :ghissue:`20099`: ``fontset`` from ``mathtext`` throwing error after setting Text ``font=``
* :ghissue:`18399`: How to get Quadmesh coordinates
* :ghissue:`15432`: Add support in matplotlib.pyplot.imshow for float16
* :ghissue:`20298`: plt.quiver linestyle option doesn't work?.....
* :ghissue:`19075`: Qt backend's Figure options to support axis units
* :ghissue:`15039`: NonUniformImage wrong image when using large values for axis
* :ghissue:`18499`: Saving as a pdf ignores ``set_clip_path`` when there is more than one of them.
* :ghissue:`15600`: Grid disappear after pcolormesh apply
* :ghissue:`20080`: API docs currently include entries for class ``__dict__``, ``__module__``, ``__weakref__``
* :ghissue:`20159`: Zoom in NavigationToolbar2Tk stops working after updating the canvas figure.
* :ghissue:`17007`: Computer Modern Glyph Error
* :ghissue:`19494`: Update azure ubuntu images to 18.04, or update texlive in CI
* :ghissue:`18841`: ScalarMappable should copy its input and allow non-arrays
* :ghissue:`20121`: Adding cmocean and CMasher to the colormaps tutorial
* :ghissue:`18154`: Deprecate plot_date()
* :ghissue:`7413`: Autoscaling has fundamental problems
* :ghissue:`19627`: Replace use of Python/C API with numpy::array_view in _tri.cpp and qhull_wrap.c
* :ghissue:`19111`: plot_directive errantly tries to run code
* :ghissue:`11007`: BUG: Plot directive fails if its content ends with a normal text line (sphinxext)
* :ghissue:`19929`: Selecting axes when customizing gives <anonymous AxesSubplot>
* :ghissue:`19578`: bisect very hard with rcParam changes
* :ghissue:`19506`: Allow saving PDF files without a page group
* :ghissue:`19906`: symlog is not in scale setting
* :ghissue:`19568`: Contour lines are rendered incorrectly when closed loops
* :ghissue:`19890`: Should ArtistList implement ``__add__``?
* :ghissue:`14405`: ENH: Add HiDPI physical to logical pixel ratio property
* :ghissue:`17139`: errorbar doesn't follow plot order
* :ghissue:`18277`: Create new sphinx gallery page for "Chart Types"
* :ghissue:`15446`: the python script in Catalina dock icon display wrong
* :ghissue:`19848`: ValueError: Key backend: '' is not a valid value for backend
* :ghissue:`1622`: zorder is not respected by all parts of ``errorbar``
* :ghissue:`17247`: Move towards making Axes.lines, Axes.patches, ... read-only views of a single child list.
* :ghissue:`19842`: UserWarning: "Trying to register the cmap '...' which already exists" is not very helpful.
* :ghissue:`7962`: pip interprets Matplotlib dev version as stable
* :ghissue:`19607`: Curves with same label not appearing in Figure options (only the last one)
* :ghissue:`17584`: NavigationToolbar2Tk behave unexpected when using it in with Tkinter Canvas
* :ghissue:`19838`: Unexpected behaviour of imshow default interpolation
* :ghissue:`7650`: anchored_artists don't support zorder argument
* :ghissue:`19687`: License doc cleanup
* :ghissue:`19635`: Multicursor updates to events for any axis
* :ghissue:`17967`: Document how to use mathtext to obtain unicode minus instead of dashes for negative numbers
* :ghissue:`8519`: Closed figures linger in memory
* :ghissue:`14175`: RFC: Allow users to force zorder in 3D plots
* :ghissue:`19464`: Quiver docs don't have a return section
* :ghissue:`18986`: fill_between issue with interpolation & NaN


Previous GitHub statistics
--------------------------


.. toctree::
    :maxdepth: 1
    :glob:
    :reversed:

    prev_whats_new/github_stats_*
